==> apache-ignite-2.15.0-src.zip: apache-ignite-2.15.0-src/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/transform/TestCacheObjectTransformerPluginProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.transform;

import org.apache.ignite.internal.cache.transform.CacheObjectTransformerManager;
import org.apache.ignite.plugin.AbstractTestPluginProvider;
import org.apache.ignite.plugin.PluginContext;
import org.jetbrains.annotations.Nullable;

/**
 *
 */
public class TestCacheObjectTransformerPluginProvider extends AbstractTestPluginProvider {
    /** Manager. */
    private final CacheObjectTransformerManager mgr;

    /**
     * @param mgr Manager.
     */
    public TestCacheObjectTransformerPluginProvider(CacheObjectTransformerManager mgr) {
        this.mgr = mgr;
    }

    /** {@inheritDoc} */
    @Override public String name() {
        return "TestCacheObjectTransformPlugin";
    }

    /** {@inheritDoc} */
    @Nullable @Override public <T> T createComponent(PluginContext ctx, Class<T> cls) {
        if (CacheObjectTransformerManager.class.equals(cls))
            return (T)mgr;

        return null;
    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/transform/TestCacheObjectTransformerPluginProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.cache.transform;

import org.apache.ignite.internal.cache.transform.CacheObjectTransformerProcessor;
import org.apache.ignite.plugin.AbstractTestPluginProvider;
import org.apache.ignite.plugin.PluginContext;
import org.jetbrains.annotations.Nullable;

/**
 *
 */
public class TestCacheObjectTransformerPluginProvider extends AbstractTestPluginProvider {
    /** Manager. */
    private final CacheObjectTransformerProcessor mgr;

    /**
     * @param mgr Manager.
     */
    public TestCacheObjectTransformerPluginProvider(CacheObjectTransformerProcessor mgr) {
        this.mgr = mgr;
    }

    /** {@inheritDoc} */
    @Override public String name() {
        return "TestCacheObjectTransformPlugin";
    }

    /** {@inheritDoc} */
    @Nullable @Override public <T> T createComponent(PluginContext ctx, Class<T> cls) {
        if (CacheObjectTransformerProcessor.class.equals(cls))
            return (T)mgr;

        return null;
    }
}
